@@ -51,7 +51,10 @@ def create_parser():
 
 
 def main():
-    from tokengen import source
+    from tokengen.source import (
+        generate_secret_value_and_push_to_azkeyvault,
+        generate_oasis_api_token
+    )
     import logging
     import os
     import sys
@@ -65,14 +68,28 @@ def main():
 
     
     """Generate the tokens and push to Azure keyvault"""
-    source.generate_secret_value_and_push_to_azkeyvault(''.join(args.secret), ''.join(args.vault_url))
+    generate_secret_value_and_push_to_azkeyvault(''.join(args.secret), ''.join(args.vault_url))
 
     """Use Pepper token and retailer to generate token"""
-    source.generate_oasis_api_token(
-        username=''.join(args.username),
-        email=''.join(args.email),
-        password=''.join(args.password), 
-        retailer=''.join(args.retailer))
+    def inject_registry_credentials():
+        if os.getenv("username") and os.getenv("email") and os.getenv("password") and os.getenv("retailer"):
+            logger.info("Using GitLab Credentials from Environment Variables")
+            generate_oasis_api_token(
+                username=''.join(os.getenv("username")),
+                email=''.join(os.getenv("email")),
+                password=''.join(os.getenv("password")), 
+                retailer=''.join(os.getenv("retailer"))
+            )
+        else:
+            logger.info("Using GitLab Credentials from CLI input values"),
+            generate_oasis_api_token(
+                username=''.join(args.username),
+                email=''.join(args.email),
+                password=''.join(args.password), 
+                retailer=''.join(args.retailer))
+
+    # Inject GitLab Credentials from Environmental variables else, use input from CLI 
+    inject_registry_credentials()
 
     print("AIFI_API_TOKEN: ", os.getenv("AIFI_API_TOKEN"))
     print("PEPPER: ", os.getenv("PEPPER"))
@@ -80,14 +97,4 @@ def main():
     print('All Processes completed!')
 
 
-# if __name__ == "__main__":
-#     import time
-
-#     start_time = time.perf_counter()
-#     main()
-#     end_time = time.perf_counter()
-
-#     timeout = end_time - start_time
-#     print(f'It took {timeout :0.2f} second(s) to complete.')
-
 
